@@ -5,7 +5,7 @@
 Chisel action class
 """
 
-from cgi import parse_header
+from cgi import parse_header # pylint: disable=deprecated-module
 from functools import partial
 from http import HTTPStatus
 from json import loads as json_loads
@@ -61,7 +61,7 @@ def action(action_callback=None, **kwargs):
 
     if action_callback is None:
         return partial(action, **kwargs)
-    return Action(action_callback, **kwargs).decorate_module(action_callback)
+    return Action(action_callback, **kwargs)
 
 
 class ActionError(Exception):
